Struct rust_icu_common::CStringVec [−][src]
pub struct CStringVec { /* fields omitted */ }Expand description
Used to simulate an array of C-style strings.
Implementations
impl CStringVec[src]
impl CStringVec[src]pub fn new(strings: &[&str]) -> Result<Self, Error>[src]
pub fn new(strings: &[&str]) -> Result<Self, Error>[src]Creates a new C string vector from the provided rust strings.
C strings are continuous byte regions that end in \0 and do not
contain \0 anywhere else.
Use as_c_array to get an unowned raw pointer to the array, to pass
into FFI C code.
pub fn as_c_array(&self) -> *const *const c_char[src]
pub fn as_c_array(&self) -> *const *const c_char[src]Returns the underlying array of C strings as a C array pointer. The array must not change after construction to ensure that this pointer remains valid.